Module: RunApi::Recraft::Types
- Defined in:
- lib/runapi/recraft/types.rb
Overview
Type definitions and constants for the Recraft image processing API.
Defined Under Namespace
Classes: CompletedImageTaskResponse, Image, ImageTaskResponse
Constant Summary collapse
- UPSCALE_IMAGE_MODELS =
Crisp upscaling model that enhances resolution while preserving detail.
%w[recraft-crisp-upscale].freeze
- REMOVE_BACKGROUND_MODELS =
Background removal model that isolates the foreground subject.
%w[recraft-remove-background].freeze